@@ -1,5 +1,10 @@
-/* ~Օʉ
- * Copyright (C) 2004 Kagetani Hideto
+/*
+ * @file cmd.c
+ * @brief R}hs֘A
+ * @author BananaJinn
+ * @version $Id: cmd.c,v 1.18 2006/03/21 14:06:22 bananajinn Exp $
+ * ~Օʉ
+ * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
  */
 
 #include <stdio.h>
@@ -11,6 +16,7 @@
 #include "cmd.h"
 #include "cmdlog.h"
 #include "ui.h"
+#include "text.h"
 
 WORD Get2bytes(BYTE *buf)
 {
@@ -516,7 +522,7 @@ int CheckReady(CMDDRIVE *drive, BOOL bWaitDisc)
 		if(SD_SENSEKEY(drive)==0x02 &&
 		   SD_ASC(drive)==0x04 &&
 		   SD_ASCQ(drive)==0x01){
-		  UIDispInfo("ł̂҂Ă܂");
+		  UIDispInfo(MSG_WAITING_READY /*"ł̂҂Ă܂"*/);
 			  /* becoming ready */
 		}
 		else if(SD_SENSEKEY(drive)==0x06 &&
@@ -542,7 +548,7 @@ int CheckReady(CMDDRIVE *drive, BOOL bWaitDisc)
 			if(bEjected==FALSE){
 			  OpenTray(drive);
 			  bEjected=TRUE;
-			  UIDispInfo("fBXN}Ă");
+			  UIDispInfo(MSG_INSERT_DISC /*"fBXN}Ă"*/);
 			}
 		  }
 		  else{
@@ -573,7 +579,7 @@ int BlankDisc(CMDDRIVE *drive, BYTE type)
 		return ret;
 	}
 
-	ret = WaitProgress(drive, "", FALSE);
+	ret = WaitProgress(drive, MSG_QUICK_BLANK /*""*/, FALSE);
 	return ret;
 }
 
@@ -609,9 +615,9 @@ int WaitProgress(CMDDRIVE *drive, const char *message, BOOL meter1)
 				indicator = Get2bytes(drive->sense_data+16);
 				if(message!=NULL){
 					if(meter1)
-						UIMeter1Update((int)((indicator*100+0x7fff)/0xffff));
+						UIMeter1Update((float)(indicator*100+0x7fff)/0xffff);
 					else
-						UIMeter2Update((int)((indicator*100+0x7fff)/0xffff));
+						UIMeter2Update((float)(indicator*100+0x7fff)/0xffff);
 				}
 			}
 #if defined(WIN32)
@@ -630,7 +636,8 @@ void DispCommandError(CMDDRIVE *drive)
 	char buf[80];
 
 	if(SD_SENSEKEY(drive)!=0){
-	  sprintf(buf, "R}hsG[(%02Xh : %X/%02X/%02X)",
+	  sprintf(buf, MSG_COMMAND_ERROR
+		  /*"R}hsG[(%02Xh : %X/%02X/%02X)"*/,
 			  drive->cmdcode,
 			  SD_SENSEKEY(drive), SD_ASC(drive), SD_ASCQ(drive));
 	  UIDispMessage(buf, UIDMT_ERROR);
@@ -652,4 +659,41 @@ int GetSubQ(CMDDRIVE *drive, DWORD lba, DWORD len)
 	return SendCmd(drive, cdb, len*16, REQ_DATAIN);
 }
 
+int SetSpeed(CMDDRIVE *drive, int read_speed, int write_speed)
+{
+  int ret;
+  WORD read_kbps, write_kbps;
+  struct _PERFORMANCEDESC *pd;
 
+  if(!REALDRIVE(drive))
+	return RET_OK;
+
+  if(DT_CD_FAMILY(drive->disc_type)){
+	read_kbps = read_speed ? (WORD)(read_speed*176.4) : 0xffff;
+	write_kbps = write_speed ? (WORD)(write_speed*176.4) : 0xffff;
+	ret = SendSetCdSpeed(drive, read_kbps, write_kbps, 0);
+	if(ret!=RET_OK){
+	  DispCommandError(drive);
+	  return ret;
+	}
+  }
+  else{
+	pd = (struct _PERFORMANCEDESC *)drive->data_buf;
+	memset(pd, 0, sizeof(struct _PERFORMANCEDESC));
+	pd->rdd = (read_speed==0 && write_speed==0) ? 1:0;
+	Set4bytes(pd->read_size, (DWORD)(read_speed*1385));
+	Set4bytes(pd->read_time, 1000);
+	Set4bytes(pd->write_size, (DWORD)(write_speed*1385));
+	Set4bytes(pd->write_time, 1000);
+
+	ret = SendSetStreaming(drive);
+#if 0	/* G[ɂȂĂpׁA */
+	if(ret!=RET_OK){
+	  DispCommandError(drive);
+	  return ret;
+	}
+#endif
+  }
+
+  return RET_OK;
+}
