@@ -1,5 +1,10 @@
-/* ~Օʉ
- * Copyright (C) 2004 Kagetani Hideto
+/*
+ * @file cmd.h
+ * @brief R}hs֘A
+ * @author BananaJinn
+ * @version $Id: cmd.h,v 1.13 2006/03/21 14:06:22 bananajinn Exp $
+ * ~Օʉ
+ * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
  */
 #ifndef __CMD_H__
 #define __CMD_H__
@@ -151,6 +156,7 @@ extern int BlankDisc(CMDDRIVE *drive, BYTE type);
 extern int WaitProgress(CMDDRIVE *drive, const char *message, BOOL meter1);
 extern void DispCommandError(CMDDRIVE *drive);
 extern int GetSubQ(CMDDRIVE *drive, DWORD lba, DWORD len);
+extern int SetSpeed(CMDDRIVE *drive, int read_speed, int write_speed);
 
 
 #ifdef __cplusplus
@@ -158,4 +164,3 @@ extern int GetSubQ(CMDDRIVE *drive, DWORD lba, DWORD len);
 #endif
 
 #endif /* !__CMD_H__ */
-
