@@ -1,5 +1,10 @@
-/* ~Օʉ
- * Copyright (c) 2004 Kagetani Hideto
+/*
+ * @file cmdlog.c
+ * @brief R}hO
+ * @author BananaJinn
+ * @version $Id: cmdlog.c,v 1.15 2006/05/18 15:23:25 bananajinn Exp $
+ * ~Օʉ
+ * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
  */
 
 #include <stdio.h>
@@ -17,6 +22,7 @@
 #include "aspi.h"
 #include "cmd.h"
 #include "cmdlog.h"
+#include "text.h"
 
 #define CMDLOGFILE 0
 
@@ -41,7 +47,7 @@ CreateLog(CMDDRIVE *pReader, CMDDRIVE *pWriter, int nWriter)
 	struct passwd *pwent;
 
 	pwent = getpwuid(getuid());
-	strcpy(path, pwent->pw_dir);
+	strncpy(path, pwent->pw_dir, sizeof(path));
 #endif
 	if(strlen(path)+strlen(fname)+1 >= _MAX_PATH){
 		return RET_NG;
@@ -58,14 +64,14 @@ CreateLog(CMDDRIVE *pReader, CMDDRIVE *pWriter, int nWriter)
 		  if(!REALDRIVE(pReader)){
 			continue;
 		  }
-		  fprintf(fp, "Ǎu : ");
+		  fprintf(fp, MSG_READER_ /*"Ǎu : "*/);
 		  pDrive = pReader;
 		}
 		else{
 		  if(!REALDRIVE(&pWriter[nDrive-1])){
 			continue;
 		  }
-		  fprintf(fp, "u%d : ", nDrive);
+		  fprintf(fp, MSG_WRITER_ /*"u%d : "*/, nDrive);
 		  pDrive = &pWriter[nDrive-1];
 		}
 
@@ -260,3 +266,4 @@ void CmdLogFree(CMDDRIVE *drive)
 		drive->cmdlog = NULL;
 	}
 }
+
