@@ -1,5 +1,10 @@
-/* ~Օʉ
- * Copyright (C) 2004 Kagetani Hideto
+/*
+ * @file netaccess.c
+ * @brief lbg[NANZX
+ * @author BananaJinn
+ * @version $Id: netaccess.c,v 1.16 2006/03/21 15:50:21 bananajinn Exp $
+ * ~Օʉ
+ * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
  */
 #if !defined(WIN32)
 # if defined(__APPLE__) && defined(__MACH__)
@@ -23,6 +28,8 @@
 
 #include "cmd.h"
 #include "netaccess.h"
+#include "ui.h"
+#include "text.h"
 
 static void SetErrorCode(SOCKCB *scb)
 {
@@ -158,8 +165,8 @@ int NACreateServer(SOCKCB *scb)
   listen(scb->u.server.listen_socket, 1);
 
 #if defined(linux)
-	  /* SJIS => EUCJP */
-  scb->iconv_desc = iconv_open("EUCJP", "SJIS");
+	  /* SJIS => local charset */
+  scb->iconv_desc = iconv_open("", "SJIS");
 #endif
   
   return RET_OK;
@@ -168,7 +175,11 @@ int NACreateServer(SOCKCB *scb)
 int NAWaitConnect(SOCKCB *scb, DWORD timeout)
 {
   struct sockaddr_in sin_remote;
+#if defined(linux)
+  socklen_t addr_size;
+#else
   int addr_size;
+#endif
   fd_set read_fds;
   int ret;
 
@@ -194,8 +205,8 @@ int NAWaitConnect(SOCKCB *scb, DWORD timeout)
 	  /* Accept connection */
   addr_size = sizeof(sin_remote);
   scb->u.server.socket_desc = accept(scb->u.server.listen_socket,
-									 (struct sockaddr *)&sin_remote,
-									 &addr_size);
+				     (struct sockaddr *)&sin_remote,
+				     &addr_size);
   if(scb->u.server.socket_desc == INVALID_SOCKET){
 	SetErrorCode(scb);
 	return RET_SOCKET;
@@ -242,12 +253,15 @@ int NAConnect(SOCKCB *scb)
 	  (struct sockaddr*)&sin_remote,
 	  sizeof(sin_remote)) == SOCKET_ERROR){
 	SetErrorCode(scb);
+	shutdown(scb->u.client.socket_desc, SD_BOTH);
+	closesocket(scb->u.client.socket_desc);
+	scb->u.client.socket_desc = 0;
 	return RET_SOCKET;
   }
 
 #if defined(linux)
-	  /* EUCJP => SJIS */
-  scb->iconv_desc = iconv_open("SJIS", "EUCJP");
+	  /* local charset => SJIS */
+  scb->iconv_desc = iconv_open("SJIS", "");
 #endif
   
   return RET_OK;
@@ -590,6 +604,7 @@ char *ConvertCharset(iconv_t iconv_desc, const char *in_string)
 	return out_string;
   }
 
+  iconv(iconv_desc, NULL, NULL, NULL, NULL);
   outbufp = out_string;
   while(inbytes > 0){
 	iconv_ret = iconv(iconv_desc,
@@ -636,7 +651,7 @@ int NASendDispCmd(SOCKCB *scb, BYTE area, BYTE percent, const char *message)
   length = sizeof(header);
   if(message != NULL){
 #if defined(linux)
-		/* EUCJP => SJIS */
+		/* local charset => SJIS */
 	message_sjis = ConvertCharset(scb->iconv_desc, message);
 	if(message_sjis == NULL){
 	  return RET_MEMERR;
@@ -732,14 +747,14 @@ int NAUIMeter2Initialize(SOCKCB *scb, const char *message)
   return NASendDispCmd(scb, 2, 0, message);
 }
 
-int NAUIMeter1Update(SOCKCB *scb, BYTE percentage)
+int NAUIMeter1Update(SOCKCB *scb, float percentage)
 {
-  return NASendDispCmd(scb, 1, percentage, NULL);
+  return NASendDispCmd(scb, 1, (BYTE)(percentage), NULL);
 }
 
-int NAUIMeter2Update(SOCKCB *scb, BYTE percentage)
+int NAUIMeter2Update(SOCKCB *scb, float percentage)
 {
-  return NASendDispCmd(scb, 2, percentage, NULL);
+  return NASendDispCmd(scb, 2, (BYTE)(percentage), NULL);
 }
 
 #if defined(WIN32)
@@ -819,3 +834,30 @@ const char *NAGetErrorMessage(SOCKCB *scb)
   return message;
 }
 
+/**
+ * \Pbg֘AG[ȂG[\
+ * @param[in]	drive	u\
+ * @param[in]	ret_value ֐ԋpl
+ * @return	\Pbg֘AG[ǂ
+ */
+BOOL DispSocketError(SOCKCB *scb, int ret_value)
+{
+  if(ret_value==RET_SOCKET){
+    const char *message = NAGetErrorMessage(scb);
+    if(message != NULL){
+      char *net_err = (char *)malloc(256);
+      if(net_err != NULL){
+	sprintf(net_err, MSG_NETWORK_ERROR_ /*"lbg[NG[ %ld : "*/,
+		scb->error_code);
+	net_err = (char *)realloc(net_err, strlen(net_err)+strlen(message)+1);
+	if(net_err != NULL){
+	  strcat(net_err, message);
+	  UIDispMessage(message, UIDMT_ERROR);
+	  free(net_err);
+	}
+      }
+      return TRUE;
+    }
+  }
+  return FALSE;
+}
