@@ -1,5 +1,10 @@
-/* ~Օʉ
- * Copyright (C) 2004 Kagetani Hideto
+/*
+ * @file scan.c
+ * @brief u
+ * @author BananaJinn
+ * @version $Id: scan.c,v 1.11 2006/06/01 16:50:51 bananajinn Exp $
+ * ~Օʉ
+ * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
  */
 #include <stdio.h>
 #include <string.h>
@@ -8,12 +13,11 @@
 #include "aspi.h"
 #include "cmd.h"
 #include "scan.h"
+#include "log.h"
 
 
 #define MAX_SCAN 16*6
 
-extern void DebugLog(char *fmt, ...);
-
 #if !defined(MACOSX)
 static BOOL IsWriterDrive(CMDDRIVE *drive)
 {
