@@ -1,12 +1,19 @@
 #!/bin/bash
-RPMTOP=~/rpm
 PROG=EnbanFukusyaYa
 TMPDIR=/tmp/$PROG
-SPECFILE=../$PROG.spec
+if [ -e /etc/vine-release ]; then
+  RPMTOP=/usr/src/vine
+  RPMBUILD=rpm
+  SPECFILE=$PROG.spec
+else
+  RPMTOP=/usr/src/redhat
+  RPMBUILD=rpmbuild
+  SPECFILE=$PROG-fc.spec
+fi
 
-SOURCE=`grep ^Source: $SPECFILE`
+SOURCE=`grep ^Source: ../$SPECFILE`
 SOURCEFILE=${SOURCE##*:\ }
-VERSION=`grep ^Version: $SPECFILE`
+VERSION=`grep ^Version: ../$SPECFILE`
 VERNUM=${VERSION##*:\ }
 PROGDIR=$PROG"-"$VERNUM
 
@@ -20,7 +27,7 @@ tar zcf $SOURCEFILE $PROGDIR
 rm -rf $PROGDIR
 popd > /dev/null
 
-cp $SPECFILE $RPMTOP/SPECS/
+cp ../$SPECFILE $RPMTOP/SPECS/
 mv $TMPDIR/$SOURCEFILE $RPMTOP/SOURCES/
 
-rpm -ba $RPMTOP/SPECS/$PROG.spec
+$RPMBUILD -ba $RPMTOP/SPECS/$SPECFILE
