@@ -9,6 +9,7 @@
 #include "common.h"
 #include "ok.xpm"
 #include "ng.xpm"
+#include "text.h"
 
 static BOOL g_Done = FALSE;
 static int g_RetCode = RET_OK;
@@ -37,59 +38,35 @@ on_cancel_clicked(GtkWidget *widget, gpointer user_data)
 }
 
 static void
-set_speed_items(GtkWidget *optmenu, gint16 default_speed, BOOL dvd)
+set_speed_items(GtkWidget *optmenu, gint16 default_speed, BOOL dvd,
+		BYTE *speeds, int num_speeds)
 {
   gint16 i, defsel;
-  gint32 speed;
-  const char *speed_items_cd[] = {
-    "1®",
-    "2®",
-    "4®",
-    "6®",
-    "8®",
-    "10®",
-    "12®",
-    "16®",
-    "20®",
-    "24®",
-    "32®",
-    "48®",
-    "52®",
-    "®",
-    NULL
-  };
-  const char *speed_items_dvd[] = {
-    "1®",
-    "2®",
-    "4®",
-    "6®",
-    "8®",
-    "10®",
-    "12®",
-    "16®",
-    "20®",
-    "24®",
-    "ɸ®",
-    NULL
-  };
-  const char **items;
   GtkWidget *menu;
   GtkWidget *menuitem;
-
-  items = dvd ? speed_items_dvd : speed_items_cd;
+  char buf[32];
 
   gtk_option_menu_remove_menu(GTK_OPTION_MENU(optmenu));
   menu = gtk_menu_new();
 
   defsel = 0;
-  for(i=0; items[i]!=NULL; i++){
-    speed = atoi(items[i]);
-    menuitem = gtk_menu_item_new_with_label(items[i]);
-    gtk_object_set_user_data(GTK_OBJECT(menuitem), GINT_TO_POINTER(speed));
+  menuitem = gtk_menu_item_new_with_label(dvd ?
+					  GT("Normal Speed"):GT("Max Speed"));
+  gtk_object_set_user_data(GTK_OBJECT(menuitem), GINT_TO_POINTER(0));
+  gtk_menu_append(GTK_MENU(menu), menuitem);
+  gtk_widget_show(menuitem);
+
+  for(i=0; i<(gint16)num_speeds; i++){
+    snprintf(buf, sizeof(buf), "%d", speeds[i]);
+    strncpy(buf+strlen(buf), GT("x"), sizeof(buf)-strlen(buf));
+    buf[sizeof(buf)-1]='\0';
+    menuitem = gtk_menu_item_new_with_label(buf);
+    gtk_object_set_user_data(GTK_OBJECT(menuitem),
+			     GINT_TO_POINTER((int)speeds[i]));
     gtk_menu_append(GTK_MENU(menu), menuitem);
     gtk_widget_show(menuitem);
-    if(speed==default_speed){
-      defsel = i;
+    if((gint16)speeds[i]==default_speed){
+      defsel = i+1;
     }
   }
   gtk_menu_set_active(GTK_MENU(menu), defsel);
@@ -100,9 +77,11 @@ static void
 set_options(OPTIONS *option)
 {
   set_speed_items(g_OptMenuReadSpeed, option->read_speed,
-		  option->flags & OPFLG_DVD);
+		  option->flags & OPFLG_DVD,
+		  option->readable_speed, option->num_readable_speed);
   set_speed_items(g_OptMenuWriteSpeed, option->write_speed,
-		  option->flags & OPFLG_DVD);
+		  option->flags & OPFLG_DVD,
+		  option->writable_speed, option->num_writable_speed);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(g_CheckTestWrite),
 			       option->test_write);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(g_CheckBUFE),
@@ -174,8 +153,8 @@ create_setting_dialog (void)
 
   setting_dlg = gtk_dialog_new ();
   gtk_object_set_data (GTK_OBJECT (setting_dlg), "setting_dlg", setting_dlg);
-  gtk_window_set_title (GTK_WINDOW (setting_dlg), "ʣ");
-  GTK_WINDOW (setting_dlg)->type = GTK_WINDOW_DIALOG;
+  gtk_window_set_title (GTK_WINDOW (setting_dlg), GT("Setting")/*"ʣ"*/);
+  /*GTK_WINDOW (setting_dlg)->type = GTK_WINDOW_DIALOG;*/
   gtk_window_set_position (GTK_WINDOW (setting_dlg), GTK_WIN_POS_CENTER);
   gtk_window_set_modal (GTK_WINDOW (setting_dlg), TRUE);
   gtk_window_set_policy (GTK_WINDOW (setting_dlg), FALSE, FALSE, FALSE);
@@ -194,7 +173,7 @@ create_setting_dialog (void)
   gtk_table_set_row_spacings (GTK_TABLE (table1), 5);
   gtk_table_set_col_spacings (GTK_TABLE (table1), 5);
 
-  label_readspeed = gtk_label_new ("ɼ®");
+  label_readspeed = gtk_label_new (GT("Read speed")/*"ɼ®"*/);
   gtk_widget_ref (label_readspeed);
   gtk_object_set_data_full (GTK_OBJECT (setting_dlg), "label_readspeed",
 			    label_readspeed,
@@ -205,7 +184,7 @@ create_setting_dialog (void)
                     (GtkAttachOptions) (0), 0, 0);
   gtk_misc_set_alignment (GTK_MISC (label_readspeed), 0, 0.5);
 
-  label_writespeed = gtk_label_new ("Ͽ®");
+  label_writespeed = gtk_label_new (GT("Write speed")/*"Ͽ®"*/);
   gtk_widget_ref (label_writespeed);
   gtk_object_set_data_full (GTK_OBJECT (setting_dlg), "label_writespeed",
 			    label_writespeed,
@@ -242,7 +221,8 @@ create_setting_dialog (void)
   gtk_option_menu_set_menu (GTK_OPTION_MENU (optmenu_writespeed),
 			    optmenu_writespeed_menu);
 
-  check_testwrite = gtk_check_button_new_with_label ("Ͽ(TestWrite)");
+  check_testwrite = gtk_check_button_new_with_label (GT("Test write")
+						     /*"Ͽ(TestWrite)"*/);
   gtk_widget_ref (check_testwrite);
   gtk_object_set_data_full (GTK_OBJECT (setting_dlg), "check_testwrite",
 			    check_testwrite,
@@ -252,7 +232,8 @@ create_setting_dialog (void)
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
 
-  check_bufe = gtk_check_button_new_with_label ("®­(BufferUnderrunFreeEnable)");
+  check_bufe = gtk_check_button_new_with_label (GT("Buffer underrun free enable")
+						/*"®­(BufferUnderrunFreeEnable)"*/);
   gtk_widget_ref (check_bufe);
   gtk_object_set_data_full (GTK_OBJECT (setting_dlg), "check_bufe",
 			    check_bufe,
@@ -262,7 +243,8 @@ create_setting_dialog (void)
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
 
-  check_onthefly = gtk_check_button_new_with_label ("ľŪϿ(on-the-fly)");
+  check_onthefly = gtk_check_button_new_with_label (GT("On the fly")
+						    /*"ľŪϿ(on-the-fly)"*/);
   gtk_widget_ref (check_onthefly);
   gtk_object_set_data_full (GTK_OBJECT (setting_dlg), "check_onthefly", check_onthefly,
                             (GtkDestroyNotify) gtk_widget_unref);
@@ -271,7 +253,8 @@ create_setting_dialog (void)
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
 
-  check_dao = gtk_check_button_new_with_label ("ɮ(Disc-at-once)");
+  check_dao = gtk_check_button_new_with_label (GT("Disc at once")
+					       /*"ɮ(Disc-at-once)"*/);
   gtk_widget_ref (check_dao);
   gtk_object_set_data_full (GTK_OBJECT (setting_dlg), "check_dao",
 			    check_dao,
@@ -281,7 +264,8 @@ create_setting_dialog (void)
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
 
-  label_temppath = gtk_label_new ("ǥ쥯ȥ");
+  label_temppath = gtk_label_new (GT("Temporary directory")
+				  /*"ǥ쥯ȥ"*/);
   gtk_widget_ref (label_temppath);
   gtk_object_set_data_full (GTK_OBJECT (setting_dlg), "label_temppath",
 			   label_temppath,
@@ -316,7 +300,7 @@ create_setting_dialog (void)
   gtk_widget_show (hbox1);
   gtk_box_pack_end (GTK_BOX (dialog_action_area1), hbox1, FALSE, FALSE, 0);
 
-  button_ok = xpm_button_new (setting_dlg, ok_xpm, "");
+  button_ok = xpm_button_new (setting_dlg, ok_xpm, GT("OK")/*""*/);
   gtk_widget_ref (button_ok);
   gtk_object_set_data_full (GTK_OBJECT (setting_dlg), "button_ok",
 							button_ok,
@@ -325,7 +309,7 @@ create_setting_dialog (void)
   gtk_widget_show (button_ok);
   gtk_box_pack_start (GTK_BOX (hbox1), button_ok, FALSE, FALSE, 0);
 
-  button_cancel = xpm_button_new (setting_dlg, ng_xpm, "");
+  button_cancel = xpm_button_new (setting_dlg, ng_xpm, GT("Cancel")/*""*/);
   gtk_widget_ref (button_cancel);
   gtk_object_set_data_full (GTK_OBJECT (setting_dlg), "button_cancel",
 			    button_cancel,
