@@ -105,15 +105,25 @@ void UIMeter2Initialize(const char *message)
 				0);
 }
 
-void UIMeter1Update(int percentage)
+void UIMeter1Update(float percentage)
 {
+  if(percentage < 0)
+    percentage = 0;
+  if(percentage > 100)
+    percentage = 100;
+
   if(g_WidgetMeter1ProgressBar!=NULL)
     gtk_progress_set_percentage(GTK_PROGRESS(g_WidgetMeter1ProgressBar),
 				percentage/100.0);
 }
 
-void UIMeter2Update(int percentage)
+void UIMeter2Update(float percentage)
 {
+  if(percentage < 0)
+    percentage = 0;
+  if(percentage > 100)
+    percentage = 100;
+
   if(g_WidgetMeter2ProgressBar!=NULL)
     gtk_progress_set_percentage(GTK_PROGRESS(g_WidgetMeter2ProgressBar),
 				percentage/100.0);
