@@ -22,8 +22,8 @@ int UIDispMessage(const char *message, int type);
 
 extern void UIMeter1Initialize(const char *message);
 extern void UIMeter2Initialize(const char *message);
-extern void UIMeter1Update(int percentage);
-extern void UIMeter2Update(int percentage);
+extern void UIMeter1Update(float percentage);
+extern void UIMeter2Update(float percentage);
 extern void UIDispInfo(const char *message);
 extern int UIFileDialog(BOOL bOpen, char *filename, int size, const char *suffix);
 extern int UINetDialog(BOOL bServer, char *remote, int size, int *port_number);
