@@ -18,7 +18,10 @@
 - (IBAction)buttonStart:(id)sender;
 - (int)openSettingDialog:(OPTIONS *)option;
 - (void)setSpeedItems:(id)target
-					  defValue:(int)defaultSpeed
-									 isdvd:(BOOL)dvd;
+			 defValue:(int)defaultSpeed
+				isdvd:(BOOL)dvd
+			speedList:(BYTE *)speeds
+			 numSpeed:(int)num_speed;
+
 
 @end
