@@ -510,6 +510,11 @@ LRESULT CEnbanFukusyaDlg::OnKickIdle(WPARAM wParam, LPARAM lParam)
 	m_CmbWriter.AddString("ISOC[Wt@C");
 	m_nWriteDriveISO = m_CmbWriter.GetCount()-1;
 
+	m_CmbReader.AddString("~ՃC[Wt@C");
+	m_nReadDriveEmg = m_CmbReader.GetCount()-1;
+	m_CmbWriter.AddString("~ՃC[Wt@C");
+	m_nWriteDriveEmg = m_CmbWriter.GetCount()-1;
+
 	m_CmbReader.AddString("lbg[N");
 	m_nReadDriveNet = m_CmbReader.GetCount()-1;
 	m_CmbWriter.AddString("lbg[N");
@@ -619,6 +624,11 @@ void CEnbanFukusyaDlg::OnOK()
 		writerp->tid = CMDDRVTYPE_ISO;
 		nWriter=1;
 	}
+	else if(sel_writer == m_nWriteDriveEmg){
+		writerp->hid = HID_VIRTUAL;
+		writerp->tid = CMDDRVTYPE_IMAGE;
+		nWriter=1;
+	}
 	else if(sel_writer == m_nWriteDriveNet){
 		writerp->hid = HID_VIRTUAL;
 		writerp->tid = CMDDRVTYPE_NET;
@@ -634,6 +644,10 @@ void CEnbanFukusyaDlg::OnOK()
 		reader.hid = HID_VIRTUAL;
 		reader.tid = CMDDRVTYPE_ISO;
 	}
+	if(sel_reader == m_nReadDriveEmg){
+		reader.hid = HID_VIRTUAL;
+		reader.tid = CMDDRVTYPE_IMAGE;
+	}
 	else if(sel_reader == m_nReadDriveNet){
 		reader.hid = HID_VIRTUAL;
 		reader.tid = CMDDRVTYPE_NET;
@@ -677,7 +691,7 @@ LRESULT CEnbanFukusyaDlg::OnUICtl(WPARAM wParam, LPARAM lParam)
 	switch(wParam){
 	case UICTL_METER1INIT:
 		m_Progress1.SetPos(0);
-		m_Progress1.SetRange(0, 100);
+		m_Progress1.SetRange(0, 1000);
 		if(lParam==NULL){
 			lpMessage = "";
 			ShowMeter1(FALSE);
@@ -690,7 +704,7 @@ LRESULT CEnbanFukusyaDlg::OnUICtl(WPARAM wParam, LPARAM lParam)
 		break;
 	case UICTL_METER2INIT:
 		m_Progress2.SetPos(0);
-		m_Progress2.SetRange(0, 100);
+		m_Progress2.SetRange(0, 1000);
 		if(lParam==NULL){
 			lpMessage = "";
 			ShowMeter2(FALSE);
@@ -702,10 +716,12 @@ LRESULT CEnbanFukusyaDlg::OnUICtl(WPARAM wParam, LPARAM lParam)
 		m_StcProgress2.SetWindowText(lpMessage);
 		break;
 	case UICTL_METER1SETPOS:
-		m_Progress1.SetPos((int)lParam);
+		m_Progress1.SetPosAnim((int)lParam);
+		TRACE("meter1=%ld\n", lParam);
 		break;
 	case UICTL_METER2SETPOS:
-		m_Progress2.SetPos((int)lParam);
+		m_Progress2.SetPosAnim((int)lParam);
+		TRACE("meter2=%ld\n", lParam);
 		break;
 	case UICTL_DISPINFO:
 		if(lParam==NULL){
