@@ -78,6 +78,48 @@
 #define IDB_TOWADA_PROGRESSFG           190
 #define IDB_TOWADA_PROGRESSBG           191
 #define IDD_REMOTE                      192
+#define IDS_WAITING_READY               193
+#define IDS_INSERT_DISC                 194
+#define IDS_QUICK_BLANK                 195
+#define IDS_COMMAND_ERROR               196
+#define IDS_READER_                     197
+#define IDS_WRITER_                     198
+#define IDS_SPEED_                      199
+#define IDS_REMAINS_                    200
+#define IDS_BUFFER_                     201
+#define IDS_CANT_GET_DISC_TYPE          202
+#define IDS_CANT_CREATE_MULTISESS_ISO   203
+#define IDS_CANT_CREATE_MULTITRACK_ISO  203
+#define IDS_READING                     204
+#define IDS_CANT_DAO                    205
+#define IDS_MIN_FORMAT                  206
+#define IDS_FORMATTING                  207
+#define IDS_NOT_BLANK                   208
+#define IDS_NOT_BLANK_QUICK_BLANK       209
+#define IDS_CLOSE_SESSION               210
+#define IDS_CLOSE_TRACK                 211
+#define IDS_SPINUP                      212
+#define IDS_RETRY_                      213
+#define IDS_TRACK_                      214
+#define IDS_WRITING_LEAD_IN             215
+#define IDS_WRITING_CDTEXT              216
+#define IDS_CANT_WRITE_CD_DAO           217
+#define IDS_SOURCE_IS_BLANK             218
+#define IDS_CAPACITY_IS_INSUFFICIENT    219
+#define IDS_TOTAL                       220
+#define IDS_NETWORK_ERROR_              221
+#define IDS_ABORTED                     222
+#define IDS_COMPLETE_SUCCESS            223
+#define IDS_ERROR_OCCURRED              224
+#define IDS_MEM_ALLOC_ERROR             225
+#define IDS_CANT_COPY_DIFFERENT_TYPE    226
+#define IDS_CANT_OPEN_IMAGE             227
+#define IDS_CANT_READ_IMAGE             228
+#define IDS_CANT_WRITE_IMAGE            229
+#define IDS_CODE_CONV_ERROR             230
+#define IDS_UNKNOWN_COMMAND             231
+#define IDS_INVALID_IMAGE_FILE          232
+#define IDS_COMPLETE_SUCCESS_AND_EJECT  233
 #define IDC_COMBO1                      1000
 #define IDC_COMBO2                      1001
 #define IDC_PROGRESS1                   1002
