@@ -37,8 +37,8 @@ int UINetDialog(BOOL bServer, char *remote, int size, int *port_number);
 
 void UIMeter1Initialize(const char *message);
 void UIMeter2Initialize(const char *message);
-void UIMeter1Update(int percentage);
-void UIMeter2Update(int percentage);
+void UIMeter1Update(float percentage);
+void UIMeter2Update(float percentage);
 void UIDispInfo(const char *message);
 
 int UISetting(OPTIONS *option);
